spacepy.toolbox.pmm — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.pmm

`spacepy.toolbox.` `pmm`(a, *b)

  print min and max of input arrays

  Parameters: | a : numpy array input array b : list arguments some additional number of arrays
  Returns: | out : list list of min, max for each array

  Examples

      >>> import spacepy.toolbox as tb
      >>> from numpy import arange
      >>> tb.pmm(arange(10), arange(10)+3)
      [[0, 9], [3, 12]]

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »